@@ -1,6 +1,8 @@
 package Proc::Class;
+use strict;
+use warnings;
 use Any::Moose;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 use 5.008001;
 our @EXPORT = qw/test_script/;
 use Proc::Class::Status;
